@@ -8,7 +8,7 @@
  = #endif
  = #endif
  =
- = #if defined(MAC_OS) || defined(MAC_OS_X_SERVER)
+ = #if defined(MAC_OS) || defined(MAC_OS_X_SERVER) || (defined(DARWIN) && defined(__DYNAMIC__))
  = #define ap_private_extern __private_extern__
  = #else
  = #define ap_private_extern
